scipy.odr.Output
================

.. currentmodule:: scipy.odr

.. autoclass:: Output

   

   .. HACK
      .. autosummary::
         :toctree:
      
         Output.__init__
         Output.pprint



   

